@@ -108,11 +108,11 @@ parse(Path0, Validators, Opts) ->
     Path = unicode:characters_to_binary(Path0),
     {Opts1, Opts2} = proplists:split(
 		       proplists:compact(Opts),
-		       [replace_macros, include_files, plain_as_atom]),
+		       [replace_macros, include_files, plain_as_atom, additional_macros]),
     Opts3 = lists:flatten(Opts1),
     try
 	Y1 = read_yaml(prep_path(Path), Opts3, []),
-	Y2 = replace_macros(Y1, Opts3),
+	Y2 = replace_macros(define_additional_macros(Y1, Opts3), Opts3),
 	Validators1 = maps:merge(Validators, validators(Opts3)),
 	{ok, (options(Validators1, Opts2))(Y2)}
     catch _:{?MODULE, Why, Ctx} ->
@@ -243,7 +243,7 @@ binary() ->
 binary(Regexp) ->
     binary(Regexp, []).
 
--spec binary(iodata(), [re:compile_option()]) -> validator(binary()).
+-spec binary(iodata(), re:compile_options()) -> validator(binary()).
 binary(Regexp, Opts) when is_list(Regexp) orelse is_binary(Regexp) ->
     fun(Val) ->
 	    Bin = to_binary(Val),
@@ -265,7 +265,7 @@ string() ->
 string(Regexp) ->
     string(Regexp, []).
 
--spec string(iodata(), [re:compile_option()]) -> validator(string()).
+-spec string(iodata(), re:compile_options()) -> validator(string()).
 string(Regexp, Opts) when is_list(Regexp) orelse is_binary(Regexp) ->
     fun(Val) ->
 	    Str = to_string(Val),
@@ -451,7 +451,7 @@ timeout(Unit, Inf) ->
 re() ->
     re([]).
 
--spec re([re:compile_option()]) -> validator(re:mp()).
+-spec re(re:compile_options()) -> validator(re:mp()).
 re(Opts) ->
     fun(Val) ->
 	    Bin = to_binary(Val),
@@ -465,7 +465,7 @@ re(Opts) ->
 glob() ->
     glob([]).
 
--spec glob([re:compile_option()]) -> validator(re:mp()).
+-spec glob(re:compile_options()) -> validator(re:mp()).
 glob(Opts) ->
     fun(Val) ->
 	    S = to_string(Val),
@@ -888,6 +888,19 @@ replace_macros(Y, Opts) ->
 	    Y
     end.
 
+define_additional_macros(Yi, Opts) ->
+    CurrentMacros = lists:flatten(proplists:get_all_values(define_macro, Yi)),
+    AdditionalMacros = proplists:get_value(additional_macros, Opts, []),
+    NewMacros = lists:foldl(fun({Key, Value}, CMs) ->
+                                     lists:keystore(Key, 1, CMs, {Key, Value})
+                             end,
+                             CurrentMacros,
+                             AdditionalMacros),
+    case NewMacros of
+        [] -> proplists:delete(define_macro, Yi);
+        _ -> [{define_macro, NewMacros} | proplists:delete(define_macro, Yi)]
+    end.
+
 -spec check_duplicated_macros([macro()]) -> [macro()].
 check_duplicated_macros(Macros) ->
     lists:foldl(
